# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/remote.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='jetpack/proto/runtime/v1alpha1/remote.proto',
  package='remote',
  syntax='proto3',
  serialized_options=b'\n\ncom.remoteB\013RemoteProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003RXX\252\002\006Remote\312\002\006Remote\342\002\022Remote\\GPBMetadata\352\002\006Remote',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+jetpack/proto/runtime/v1alpha1/remote.proto\x12\x06remote\"[\n\x11RemoteCallRequest\x12)\n\x10qualified_symbol\x18\x01 \x01(\tR\x0fqualifiedSymbol\x12\x1b\n\tjson_args\x18\x02 \x01(\tR\x08jsonArgs\"7\n\x12RemoteCallResponse\x12!\n\x0cjson_results\x18\x01 \x01(\tR\x0bjsonResults\"7\n\x10LaunchJobRequest\x12#\n\x03job\x18\x01 \x01(\x0b\x32\x11.remote.RemoteJobR\x03job\"\x13\n\x11LaunchJobResponse\"?\n\x18LaunchBlockingJobRequest\x12#\n\x03job\x18\x01 \x01(\x0b\x32\x11.remote.RemoteJobR\x03job\"C\n\x19LaunchBlockingJobResponse\x12&\n\x06result\x18\x01 \x01(\x0b\x32\x0e.remote.ResultR\x06result\"\xbd\x01\n\tRemoteJob\x12\'\n\x0f\x63ontainer_image\x18\x01 \x01(\tR\x0e\x63ontainerImage\x12)\n\x10qualified_symbol\x18\x02 \x01(\tR\x0fqualifiedSymbol\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12!\n\x0c\x65ncoded_args\x18\x04 \x01(\x0cR\x0b\x65ncodedArgs\x12\x1b\n\tmodule_id\x18\x05 \x01(\tR\x08moduleId\"R\n\x06Result\x12#\n\x05value\x18\x01 \x01(\x0b\x32\r.remote.ValueR\x05value\x12#\n\x05\x65rror\x18\x02 \x01(\x0b\x32\r.remote.ErrorR\x05\x65rror\"m\n\x05\x45rror\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.remote.ErrorCodeR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12#\n\rencoded_error\x18\x03 \x01(\x0cR\x0c\x65ncodedError\",\n\x05Value\x12#\n\rencoded_value\x18\x01 \x01(\x0cR\x0c\x65ncodedValue*7\n\tErrorCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07RUNTIME\x10\x64\x12\x10\n\x0b\x41PPLICATION\x10\xc8\x01\x32\xf7\x01\n\x0eRemoteExecutor\x12\x45\n\nRemoteCall\x12\x19.remote.RemoteCallRequest\x1a\x1a.remote.RemoteCallResponse\"\x00\x12\x42\n\tLaunchJob\x12\x18.remote.LaunchJobRequest\x1a\x19.remote.LaunchJobResponse\"\x00\x12Z\n\x11LaunchBlockingJob\x12 .remote.LaunchBlockingJobRequest\x1a!.remote.LaunchBlockingJobResponse\"\x00\x42\x85\x01\n\ncom.remoteB\x0bRemoteProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03RXX\xaa\x02\x06Remote\xca\x02\x06Remote\xe2\x02\x12Remote\\GPBMetadata\xea\x02\x06Remoteb\x06proto3'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='remote.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLICATION', index=2, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=850,
  serialized_end=905,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
UNKNOWN = 0
RUNTIME = 100
APPLICATION = 200



_REMOTECALLREQUEST = _descriptor.Descriptor(
  name='RemoteCallRequest',
  full_name='remote.RemoteCallRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='qualified_symbol', full_name='remote.RemoteCallRequest.qualified_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='qualifiedSymbol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_args', full_name='remote.RemoteCallRequest.json_args', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=146,
)


_REMOTECALLRESPONSE = _descriptor.Descriptor(
  name='RemoteCallResponse',
  full_name='remote.RemoteCallResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_results', full_name='remote.RemoteCallResponse.json_results', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonResults', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=203,
)


_LAUNCHJOBREQUEST = _descriptor.Descriptor(
  name='LaunchJobRequest',
  full_name='remote.LaunchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='remote.LaunchJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='job', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=260,
)


_LAUNCHJOBRESPONSE = _descriptor.Descriptor(
  name='LaunchJobResponse',
  full_name='remote.LaunchJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=281,
)


_LAUNCHBLOCKINGJOBREQUEST = _descriptor.Descriptor(
  name='LaunchBlockingJobRequest',
  full_name='remote.LaunchBlockingJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='remote.LaunchBlockingJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='job', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=346,
)


_LAUNCHBLOCKINGJOBRESPONSE = _descriptor.Descriptor(
  name='LaunchBlockingJobResponse',
  full_name='remote.LaunchBlockingJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='remote.LaunchBlockingJobResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='result', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=415,
)


_REMOTEJOB = _descriptor.Descriptor(
  name='RemoteJob',
  full_name='remote.RemoteJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_image', full_name='remote.RemoteJob.container_image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='containerImage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qualified_symbol', full_name='remote.RemoteJob.qualified_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='qualifiedSymbol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='remote.RemoteJob.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded_args', full_name='remote.RemoteJob.encoded_args', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodedArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_id', full_name='remote.RemoteJob.module_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='moduleId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=607,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='remote.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='remote.Result.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='remote.Result.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=691,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='remote.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='remote.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='remote.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded_error', full_name='remote.Error.encoded_error', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodedError', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=802,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='remote.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoded_value', full_name='remote.Value.encoded_value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodedValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=848,
)

_LAUNCHJOBREQUEST.fields_by_name['job'].message_type = _REMOTEJOB
_LAUNCHBLOCKINGJOBREQUEST.fields_by_name['job'].message_type = _REMOTEJOB
_LAUNCHBLOCKINGJOBRESPONSE.fields_by_name['result'].message_type = _RESULT
_RESULT.fields_by_name['value'].message_type = _VALUE
_RESULT.fields_by_name['error'].message_type = _ERROR
_ERROR.fields_by_name['code'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['RemoteCallRequest'] = _REMOTECALLREQUEST
DESCRIPTOR.message_types_by_name['RemoteCallResponse'] = _REMOTECALLRESPONSE
DESCRIPTOR.message_types_by_name['LaunchJobRequest'] = _LAUNCHJOBREQUEST
DESCRIPTOR.message_types_by_name['LaunchJobResponse'] = _LAUNCHJOBRESPONSE
DESCRIPTOR.message_types_by_name['LaunchBlockingJobRequest'] = _LAUNCHBLOCKINGJOBREQUEST
DESCRIPTOR.message_types_by_name['LaunchBlockingJobResponse'] = _LAUNCHBLOCKINGJOBRESPONSE
DESCRIPTOR.message_types_by_name['RemoteJob'] = _REMOTEJOB
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemoteCallRequest = _reflection.GeneratedProtocolMessageType('RemoteCallRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTECALLREQUEST,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.RemoteCallRequest)
  })
_sym_db.RegisterMessage(RemoteCallRequest)

RemoteCallResponse = _reflection.GeneratedProtocolMessageType('RemoteCallResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTECALLRESPONSE,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.RemoteCallResponse)
  })
_sym_db.RegisterMessage(RemoteCallResponse)

LaunchJobRequest = _reflection.GeneratedProtocolMessageType('LaunchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _LAUNCHJOBREQUEST,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.LaunchJobRequest)
  })
_sym_db.RegisterMessage(LaunchJobRequest)

LaunchJobResponse = _reflection.GeneratedProtocolMessageType('LaunchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _LAUNCHJOBRESPONSE,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.LaunchJobResponse)
  })
_sym_db.RegisterMessage(LaunchJobResponse)

LaunchBlockingJobRequest = _reflection.GeneratedProtocolMessageType('LaunchBlockingJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _LAUNCHBLOCKINGJOBREQUEST,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.LaunchBlockingJobRequest)
  })
_sym_db.RegisterMessage(LaunchBlockingJobRequest)

LaunchBlockingJobResponse = _reflection.GeneratedProtocolMessageType('LaunchBlockingJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _LAUNCHBLOCKINGJOBRESPONSE,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.LaunchBlockingJobResponse)
  })
_sym_db.RegisterMessage(LaunchBlockingJobResponse)

RemoteJob = _reflection.GeneratedProtocolMessageType('RemoteJob', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEJOB,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.RemoteJob)
  })
_sym_db.RegisterMessage(RemoteJob)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.Result)
  })
_sym_db.RegisterMessage(Result)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.Error)
  })
_sym_db.RegisterMessage(Error)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.remote_pb2'
  # @@protoc_insertion_point(class_scope:remote.Value)
  })
_sym_db.RegisterMessage(Value)


DESCRIPTOR._options = None

_REMOTEEXECUTOR = _descriptor.ServiceDescriptor(
  name='RemoteExecutor',
  full_name='remote.RemoteExecutor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=908,
  serialized_end=1155,
  methods=[
  _descriptor.MethodDescriptor(
    name='RemoteCall',
    full_name='remote.RemoteExecutor.RemoteCall',
    index=0,
    containing_service=None,
    input_type=_REMOTECALLREQUEST,
    output_type=_REMOTECALLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LaunchJob',
    full_name='remote.RemoteExecutor.LaunchJob',
    index=1,
    containing_service=None,
    input_type=_LAUNCHJOBREQUEST,
    output_type=_LAUNCHJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LaunchBlockingJob',
    full_name='remote.RemoteExecutor.LaunchBlockingJob',
    index=2,
    containing_service=None,
    input_type=_LAUNCHBLOCKINGJOBREQUEST,
    output_type=_LAUNCHBLOCKINGJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REMOTEEXECUTOR)

DESCRIPTOR.services_by_name['RemoteExecutor'] = _REMOTEEXECUTOR

# @@protoc_insertion_point(module_scope)
